# Rich Integration API

Integration with the Rich library for colorful output.

## RichPrinter

::: pyreprint.integrations.rich.RichPrinter

## Functions

### rprint

::: pyreprint.integrations.rich.rprint

### rule

::: pyreprint.integrations.rich.rule

### panel

::: pyreprint.integrations.rich.panel

## PrettyPrint

### pprint

::: pyreprint.integrations.pprint.pprint

### pformat

::: pyreprint.integrations.pprint.pformat

### PrettyPrinter

::: pyreprint.integrations.pprint.PrettyPrinter

